@@ -133,9 +133,13 @@ namespace Aws
           AWSError<CoreErrors> BuildAWSError(const std::shared_ptr<Http::HttpResponse>& httpResponse) const override;
 
         protected:
-          const Aws::Utils::Cbor::CborValue& GetCborPayloadFromError(const AWSError<CoreErrors>&) const;
           static Aws::Utils::Cbor::CborValue GetCborPayloadHttpResponse(const Http::HttpResponse& httpResponse);
         };
 
+        class AWS_CORE_API RpcV2ErrorMarshallerQueryCompatible : public RpcV2ErrorMarshaller {
+        protected:
+          void MarshallError(AWSError<CoreErrors>&, const Http::HttpResponse&) const override;
+        };
+
     } // namespace Client
 } // namespace Aws
